import request from '@/utils/request'

// 查询资产分类列表
export function listClassification(query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'classificationCode') {
        params.classification_code = query[key]
      } else if (key === 'classificationName') {
        params.classification_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/classifications/list',
    method: 'get',
    params: params
  })
}

// 查询资产分类详情
export function getClassification(id) {
  return request({
    url: '/asset/classifications/' + id,
    method: 'get'
  })
}

// 新增资产分类
export function addClassification(data) {
  return request({
    url: '/asset/classifications/create',
    method: 'post',
    data: data
  })
}

// 修改资产分类
export function updateClassification(data) {
  return request({
    url: '/asset/classifications/' + data.id,
    method: 'put',
    data: data
  })
}

// 删除资产分类
export function delClassification(id, lastModUserId) {
  return request({
    url: '/asset/classifications/' + id,
    method: 'delete',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 禁用资产分类
export function disableClassification(id, lastModUserId) {
  return request({
    url: '/asset/classifications/' + id + '/status/disable',
    method: 'put',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 启用资产分类
export function enableClassification(id, lastModUserId) {
  return request({
    url: '/asset/classifications/' + id + '/status/enable',
    method: 'put',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 批量删除资产分类
export function delClassificationBatch(ids, lastModUserId) {
  return request({
    url: '/asset/classifications/batch',
    method: 'delete',
    data: ids,
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 获取资产分类树形结构
export function getClassificationTree(query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'classificationCode') {
        params.classification_code = query[key]
      } else if (key === 'classificationName') {
        params.classification_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/classifications/tree',
    method: 'get',
    params: params
  })
}

// 根据父ID查询子分类
export function getChildClassifications(parentId, query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'classificationCode') {
        params.classification_code = query[key]
      } else if (key === 'classificationName') {
        params.classification_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/classifications/children/' + parentId,
    method: 'get',
    params: params
  })
}

// 检查分类是否被使用
export function checkClassificationInUse(id) {
  return request({
    url: '/asset/classifications/' + id + '/check',
    method: 'get'
  })
}

// 导出资产分类
export function exportClassification(query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'classificationCode') {
        params.classification_code = query[key]
      } else if (key === 'classificationName') {
        params.classification_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/classifications/export',
    method: 'get',
    params: params
  })
} 