import request from '@/utils/request'

// 获取资产列表
export function listAssets(query) {
  return request({
    url: '/asset/list',
    method: 'get',
    params: query
  })
}

// 获取资产详情
export function getAsset(assetCode) {
  return request({
    url: `/asset/${assetCode}`,
    method: 'get',
  })
}

// 新增资产
export function addAsset(data) {
  return request({
    url: '/asset/create',
    method: 'post',
    data: data
  })
}

// 修改资产
export function updateAsset(data) {
  return request({
    url: `/asset/${data.assetCode}`,
    method: 'put',
    data: data
  })
}

// 删除资产
export function deleteAsset(assetCode) {
  return request({
    url: '/asset/delete',
    method: 'delete',
    params: { assetCode }
  })
}

// 批量删除资产
export function deleteAssets(assetCodes) {
  return request({
    url: '/asset/batch/delete',
    method: 'delete',
    data: { assetCodes }
  })
}

// 导出资产
export function exportAsset(query) {
  return request({
    url: '/asset/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}

// 下载资产导入模板
export function downloadTemplate() {
  return request({
    url: '/asset/template/download',
    method: 'get',
    responseType: 'blob'
  })
}

// 获取资产位置树
export function listAssetLocationTree() {
  return request({
    url: '/asset/location/tree',
    method: 'get'
  })
}

// 获取公司列表
export function listCompanies() {
  return request({
    url: '/admin/company/getAllCompanyDetails',
    method: 'get'
  })
}

// 获取用户列表
export function listUsers() {
  return request({
    url: '/v1/member/list',
    method: 'get',
  })
}

// 上传资产图片
export function uploadAssetImage(data) {
  return request({
    url: '/asset/upload/image',
    method: 'post',
    data: data
  })
}

/**
 * 批量打印资产标签
 * @param {Array} assetCodes 资产编码数组
 * @returns {Object} 请求结果
 */
export function printAssetLabels(assetCodes) {
  return request({
    url: '/asset/print',
    method: 'post',
    data: assetCodes
  })
}

// 检查资产编码是否存在
export function checkAssetCode(code) {
  return request({
    url: '/asset/check/code',
    method: 'get',
    params: { code }
  })
}

// 获取标签配置
export function getLabelConfig() {
  return request({
    url: '/asset/label',
    method: 'get'
  })
} 