import request from '@/utils/request'

// 查询资产标签列表
export function listLabelTemplates(query) {
  return request({
    url: '/asset/label/list',
    method: 'get',
    params: query
  })
}

// 获取标签模板详情
export function getLabelTemplate(id) {
  return request({
    url: '/asset/label/template/' + id,
    method: 'get'
  })
}

// 新增资产标签
export function addLabelTemplate(data) {
  return request({
    url: '/asset/label',
    method: 'post',
    data: data
  })
}

// 修改资产标签
export function updateLabelTemplate(id, data) {
  return request({
    url: '/asset/label/' + id,
    method: 'put',
    data: data
  })
}

// 删除标签模板
export function deleteLabelTemplate(id) {
  return request({
    url: '/asset/label/template/' + id,
    method: 'delete'
  })
}

// 设置默认模板
export function setDefaultTemplate(id) {
  return request({
    url: '/asset/label/template/default/' + id,
    method: 'put'
  })
}

// 获取可用的标签字段
export function getLabelFields() {
  const fieldData = [
    { id: 1, name: '资产名称' },
    { id: 2, name: '资产分类' },
    { id: 3, name: '资产编码' },
    { id: 4, name: '资产位置' },
    { id: 5, name: '品牌' },
    { id: 6, name: '型号' },
    { id: 7, name: '设备序列号' },
    { id: 8, name: '管理员' },
    { id: 9, name: '保养到期时间' },
    { id: 10, name: '保养说明' },
    { id: 11, name: '使用部门' }
  ];
  
  return Promise.resolve({
    code: '0000000000000000',
    msg: 'success',
    data: fieldData
  });
}

// 获取字段对应的示例值
export function getFieldSampleValues() {
  return {
    '1': 'ThinkPad笔记本',
    '2': '电脑/笔记本电脑',
    '3': 'ASSET-001',
    '4': '研发部-A区',
    '5': 'Lenovo',
    '6': 'X1 Carbon',
    '7': 'SN12345678',
    '8': '张三',
    '9': '2024-12-31',
    '10': '每季度保养一次',
    '11': '研发部'
  };
}

// 打印标签预览
export function previewLabel(data) {
  return request({
    url: '/asset/label/preview',
    method: 'post',
    data: data
  })
}

// 打印标签
export function printLabel(data) {
  return request({
    url: '/asset/label/print',
    method: 'post',
    data: data
  })
} 