import request from '@/utils/request'

// 查询资产位置列表
export function listLocation(query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'locationCode') {
        params.location_code = query[key]
      } else if (key === 'locationName') {
        params.location_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/locations/list',
    method: 'get',
    params: params
  })
}

// 查询资产位置详情
export function getLocation(id) {
  return request({
    url: '/asset/locations/' + id,
    method: 'get'
  })
}

// 新增资产位置
export function addLocation(data) {
  return request({
    url: '/asset/locations/create',
    method: 'post',
    data: data
  })
}

// 修改资产位置
export function updateLocation(data) {
  return request({
    url: '/asset/locations/' + data.id,
    method: 'put',
    data: data
  })
}

// 删除资产位置
export function delLocation(id, lastModUserId) {
  return request({
    url: '/asset/locations/' + id,
    method: 'delete',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 禁用资产位置
export function disableLocation(id, lastModUserId) {
  return request({
    url: '/asset/locations/' + id + '/status/disable',
    method: 'put',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 启用资产位置
export function enableLocation(id, lastModUserId) {
  return request({
    url: '/asset/locations/' + id + '/status/enable',
    method: 'put',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 批量删除资产位置
export function delLocationBatch(ids, lastModUserId) {
  return request({
    url: '/asset/locations/batch',
    method: 'delete',
    data: ids,
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 获取资产位置树形结构
export function getLocationTree(query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'locationCode') {
        params.location_code = query[key]
      } else if (key === 'locationName') {
        params.location_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/locations/tree',
    method: 'get',
    params: params
  })
}

// 根据父ID查询子位置
export function getChildLocations(parentId, query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'locationCode') {
        params.location_code = query[key]
      } else if (key === 'locationName') {
        params.location_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/locations/children/' + parentId,
    method: 'get',
    params: params
  })
}

// 检查位置是否被使用
export function checkLocationInUse(id) {
  return request({
    url: '/asset/locations/' + id + '/check',
    method: 'get'
  })
}

// 检查编码唯一性
export function checkLocationCode(id, locationCode) {
  return request({
    url: '/asset/locations/check/code',
    method: 'get',
    params: {
      id: id,
      location_code: locationCode
    }
  })
}

// 导出资产位置
export function exportLocation(query) {
  // 将驼峰命名转换为下划线命名
  const params = {}
  if (query) {
    Object.keys(query).forEach(key => {
      if (key === 'locationCode') {
        params.location_code = query[key]
      } else if (key === 'locationName') {
        params.location_name = query[key]
      } else {
        params[key] = query[key]
      }
    })
  }
  
  return request({
    url: '/asset/locations/export',
    method: 'get',
    params: params
  })
} 