import request from '@/utils/request'

// 查询楼宇列表
export function getBuildingList(query) {
  return request({
    url: '/room/building/list',
    method: 'get',
    params: query
  })
}

// 查询楼宇详细
export function getBuildingDetail(id) {
  return request({
    url: `/room/building/${id}`,
    method: 'get'
  })
}

// 新增楼宇
export function addBuilding(data) {
  // 处理字段名映射，确保前端驼峰命名与后端下划线命名正确对应
  const processedData = {
    ...data,
    buildingTags: data.buildingTags,
    isHot: data.isHot,
    imageUrl: data.buildingImage,
  }

  // 删除undefined的属性
  Object.keys(processedData).forEach(key => {
    if (processedData[key] === undefined) {
      delete processedData[key]
    }
  })

  return request({
    url: '/room/building/add',
    method: 'post',
    data: processedData
  })
}

// 修改楼宇
export function updateBuilding(data) {
  // 处理字段名映射，确保前端驼峰命名与后端下划线命名正确对应
  const processedData = {
    ...data,
    buildingTags: data.buildingTags,
    isHot: data.isHot,
    imageUrl: data.buildingImage
  }

  // 删除undefined的属性
  Object.keys(processedData).forEach(key => {
    if (processedData[key] === undefined) {
      delete processedData[key]
    }
  })

  return request({
    url: '/room/building/edit',
    method: 'post',
    data: processedData
  })
}

// 删除楼宇
export function deleteBuilding(ids) {
  return request({
    url: `/room/building/remove/${ids}`,
    method: 'post'
  })
}

// 获取楼宇统计信息
export function getBuildingStatistics(id) {
  return request({
    url: `/room/building/${id}/statistics`,
    method: 'get'
  })
}

// 查询楼层列表
export function getFloorList(query) {
  return request({
    url: `/room/floor/list/${query}`,
    method: 'get'
  })
}

// 获取楼层详情
export function getFloorDetail(id) {
  return request({
    url: `/room/floor/${id}`,
    method: 'get'
  })
}

// 新增楼层
export function addFloor(data) {
  return request({
    url: '/room/floor/add',
    method: 'post',
    data: data
  })
}

// 修改楼层
export function updateFloor(data) {
  return request({
    url: '/room/floor/edit',
    method: 'post',
    data: data
  })
}

// 删除楼层
export function deleteFloor(ids) {
  return request({
    url: `/room/floor/remove/${ids}`,
    method: 'post'
  })
}

// 根据楼宇ID获取楼层列表
export function getFloorListByBuilding(buildingId) {
  return request({
    url: `/room/floor/building/${buildingId}`,
    method: 'get'
  })
} 

// 收支账号管理
export function getAllAccounts() {
  return request({
    url: `/admin/account/getAllAccounts`,
    method: 'get'
  })
} 