import request from '@/utils/request'

// 招商团队相关API
export function getMerchantTeamList(params) {
  return request({
    url: '/bizTeam/list',
    method: 'get',
    params
  })
}

export function getMerchantTeamDetail(id) {
  return request({
    url: `/bizTeam/${id}`,
    method: 'get'
  })
}
// 根据项目ID获取招商团队信息
export function getMerchantTeamByProjectId(projectId) {
  return request({
    url: `/bizTeam/project/${projectId}`,
    method: 'get'
  })
}

export function addMerchantTeam(data) {
  return request({
    url: '/bizTeam',
    method: 'post',
    data
  })
}

export function updateMerchantTeam(data) {
  return request({
    url: '/bizTeam',
    method: 'put',
    data
  })
}

export function deleteMerchantTeam(id, userId) {
  return request({
    url: `/bizTeam/${id}`,
    method: 'delete',
    params: { userId }
  })
}

export function checkTeamName(params) {
  return request({
    url: '/bizTeam/checkName',
    method: 'get',
    params
  })
}

export function getProjectsList() {
  return request({
    url: '/bizTeam/projects',
    method: 'get'
  })
}

// 招商人员相关API
export function getMerchantPersonnelList(data) {
  return request({
    url: '/bizPersonnel/queryAllPersonnel',
    method: 'post',
    data
  })
}

export function getPersonnelByTeamId(teamId) {
  return request({
    url: `/business/personnel/team/${teamId}`,
    method: 'get'
  })
}

export function getPersonnelDetail(id) {
  return request({
    url: `/business/personnel/${id}`,
    method: 'get'
  })
}

export function addMerchantPersonnel(data) {
  return request({
    url: '/bizPersonnel',
    method: 'post',
    data
  })
}

export function batchAddMerchantPersonnel(data) {
  return request({
    url: '/bizPersonnel/batch',
    method: 'post',
    data
  })
}

export function removeMerchantPersonnel(id, userId) {
  return request({
    url: `/bizPersonnel/${id}`,
    method: 'delete',
    params: { userId }
  })
}

export function checkMemberExists(params) {
  return request({
    url: '/bizPersonnel/checkMember',
    method: 'get',
    params
  })
}

// 成员管理相关API
export function getDepartmentTree() {
  return request({
    url: '/business/member/dept/tree',
    method: 'get'
  })
}

export function getDepartmentMemberTree() {
  return request({
    url: '/business/member/tree',
    method: 'get'
  })
}

export function getManagerList() {
  return request({
    url: '/business/member/managers',
    method: 'get'
  })
}

export function getMemberList(params) {
  return request({
    url: '/business/member/list',
    method: 'get',
    params
  })
}

export function getMembersByDeptId(deptId) {
  return request({
    url: `/business/member/dept/${deptId}`,
    method: 'get'
  })
}

export function getMemberDetail(memberId) {
  return request({
    url: `/business/member/${memberId}`,
    method: 'get'
  })
}

// 获取项目列表
export function getProjectList() {
  return request({
    url: '/project/list',
    method: 'get'
  })
}

// 获取线索数量
export function getClueCount(personnelId) {
  return request({
    url: `/merchant/clue/count/${personnelId}`,
    method: 'get'
  })
}

// 获取意向客户数量
export function getIntentCustomerCount(personnelId) {
  return request({
    url: `/merchant/intent-customer/count/${personnelId}`,
    method: 'get'
  })
}

// 获取合同数量
export function getContractCount(personnelId) {
  return request({
    url: `/merchant/contract/count/${personnelId}`,
    method: 'get'
  })
}

// 标签分组相关API
export function getTagGroupList(params) {
  return request({
    url: '/business/tag-group/list',
    method: 'get',
    params
  })
}

export function getAllTagGroups() {
  return request({
    url: '/business/tag-group/all',
    method: 'get'
  })
}

export function getTagGroupDetail(id) {
  return request({
    url: `/business/tag-group/${id}`,
    method: 'get'
  })
}

export function addTagGroup(data) {
  return request({
    url: '/business/tag-group',
    method: 'post',
    data
  })
}

export function updateTagGroup(data) {
  return request({
    url: '/business/tag-group',
    method: 'put',
    data
  })
}

export function deleteTagGroup(id) {
  return request({
    url: `/business/tag-group/${id}`,
    method: 'delete'
  })
}

export function checkTagGroupName(params) {
  return request({
    url: '/business/tag-group/check-name',
    method: 'get',
    params
  })
}

// 标签相关API
export function getTagList(params) {
  return request({
    url: '/business/tag/list',
    method: 'get',
    params
  })
}

export function getTagListByGroupId(groupId) {
  return request({
    url: `/business/tag/group/${groupId}`,
    method: 'get'
  })
}

export function getTagDetail(id) {
  return request({
    url: `/business/tag/${id}`,
    method: 'get'
  })
}

export function addTag(data) {
  return request({
    url: '/business/tag',
    method: 'post',
    data
  })
}

export function updateTag(data) {
  return request({
    url: '/business/tag',
    method: 'put',
    data
  })
}

export function deleteTag(id) {
  return request({
    url: `/business/tag/${id}`,
    method: 'delete'
  })
}

export function checkTagName(params) {
  return request({
    url: '/business/tag/check-name',
    method: 'get',
    params
  })
}

// 线索状态API
export function getLeadStatusList() {
  return request({
    url: '/bizLead/status/list',
    method: 'get'
  })
}

export function getLeadStatusDetail(id) {
  return request({
    url: `/bizLead/status/${id}`,
    method: 'get'
  })
}

export function addLeadStatus(data) {
  return request({
    url: '/bizLead/status',
    method: 'post',
    data
  })
}

export function updateLeadStatus(data) {
  return request({
    url: '/bizLead/status',
    method: 'put',
    data
  })
}

export function deleteLeadStatus(id, userId) {
  return request({
    url: `/bizLead/status/${id}`,
    method: 'delete',
    params: { userId }
  })
}

export function checkLeadStatusName(statusName) {
  return request({
    url: '/bizLead/status/checkName',
    method: 'get',
    params: { statusName }
  })
}

// 线索管理API
export function getLeadList(params) {
  return request({
    url: '/bizLead/list',
    method: 'get',
    params
  })
}

export function getMyLeadList(params) {
  return request({
    url: '/bizLead/myLeads',
    method: 'get',
    params
  })
}

export function getAllLeadList(params) {
  return request({
    url: '/bizLead/allLeads',
    method: 'get',
    params
  })
}

export function getPublicLeadList(params) {
  return request({
    url: '/bizLead/publicLeads',
    method: 'get',
    params
  })
}

export function getLeadDetail(id) {
  return request({
    url: `/bizLead/${id}`,
    method: 'get'
  })
}

export function addLead(data) {
  return request({
    url: '/bizLead',
    method: 'post',
    data
  })
}

export function updateLead(data) {
  return request({
    url: '/bizLead',
    method: 'put',
    data
  })
}

export function changeLeadStatus(id, statusId, userId) {
  return request({
    url: `/bizLead/${id}/status`,
    method: 'put',
    params: { statusId, userId }
  })
}

export function changeLeadPersonnel(id, personnelId, userId) {
  return request({
    url: `/bizLead/${id}/personnel`,
    method: 'put',
    params: { personnelId, userId }
  })
}

export function checkLeadPhone(phone) {
  return request({
    url: '/bizLead/checkPhone',
    method: 'get',
    params: { phone }
  })
}

export function convertLeadToIntention(id, userId) {
  return request({
    url: `/bizLead/${id}/convert`,
    method: 'post',
    params: { userId }
  })
}

export function deleteLead(id, userId) {
  return request({
    url: `/bizLead/${id}`,
    method: 'delete',
    params: { userId }
  })
}

export function getLeadFollowHistory(leadId) {
  return request({
    url: `/bizLead/${leadId}/followHistory`,
    method: 'get'
  })
}

// 意向客户相关API
export function getCustomerDetail(id) {
  return request({
    url: `/bizCustomer/${id}`,
    method: 'get'
  })
}

export function createCustomer(data) {
  return request({
    url: '/bizCustomer',
    method: 'post',
    data
  })
}

export function updateCustomer(data) {
  return request({
    url: '/bizCustomer',
    method: 'put',
    data
  })
}

export function deleteCustomer(id) {
  return request({
    url: `/bizCustomer/${id}`,
    method: 'delete'
  })
}

export function changeCustomerPersonnel(id, personnelId) {
  return request({
    url: `/bizCustomer/personnel/${id}/${personnelId}`,
    method: 'put'
  })
}

export function changeCustomerStatus(id, statusId) {
  return request({
    url: `/bizCustomer/status/${id}/${statusId}`,
    method: 'put'
  })
}

export function checkCustomerPhone(params) {
  return request({
    url: '/bizCustomer/checkPhone',
    method: 'get',
    params
  })
}

export function getMyCustomerList(data) {
  return request({
    url: '/bizCustomer/myCustomer',
    method: 'post',
    data
  })
}

export function getAllCustomerList(data) {
  return request({
    url: '/bizCustomer/allCustomer',
    method: 'post',
    data
  })
}

export function getPublicCustomerList(data) {
  return request({
    url: '/bizCustomer/publicCustomer',
    method: 'post',
    data
  })
}

export function followCustomer(data) {
  return request({
    url: '/bizCustomer/follow',
    method: 'post',
    data
  })
}

export function getCustomerFollowHistory(customerId) {
  return request({
    url: `/bizCustomer/followHistory/${customerId}`,
    method: 'get'
  })
}

export function assignCustomer(id, params) {
  return request({
    url: `/bizCustomer/${id}/assign`,
    method: 'post',
    params
  })
}

export function returnCustomerToPublic(id, userId) {
  return request({
    url: `/bizCustomer/returnToPublic/${id}`,
    method: 'post',
    params: { userId }
  })
}

export function getCustomerTagGroups() {
  return request({
    url: '/bizCustomer/tags/groups',
    method: 'get'
  })
}

export function saveCustomerTags(data) {
  return request({
    url: '/bizCustomer/tags',
    method: 'post',
    data
  })
}

// 获取客户状态列表
export function getCustomerStatusList() {
  return request({
    url: '/bizCustomer/status/list',
    method: 'get'
  })
}
