import Vue from 'vue'
import VueRouter from 'vue-router'
import Layout from '@/layout/index'
import systemRoutes from './modules/system'
import projectRoutes from './modules/project'
import financeRoutes from './modules/finance'
import merchantRoutes from './modules/merchant'

Vue.use(VueRouter)

const routes = [
  {
    path: '/',
    component: () => import('@/layout/index'),
    redirect: '/home',
    hidden: true
  },
  {
    path: '/home',
    component: () => import('@/layout/index'),
    children: [
      {
        path: '',
        name: 'Home',
        component: () => import('../views/Home.vue'),
        meta: { title: '首页', icon: 'el-icon-s-home' }
      }
    ],
    meta: { title: '首页', icon: 'el-icon-s-home' }
  },
  systemRoutes,
  projectRoutes,
  financeRoutes,
  merchantRoutes,
  {
    path: '/asset',
    component: Layout,
    name: 'Asset',
    meta: { title: '资产管理', icon: 'el-icon-s-management' },
    children: [
      {
        path: 'location',
        component: () => import('@/views/asset/location/index'),
        name: 'AssetLocation',
        meta: { title: '资产位置设置', icon: 'el-icon-location' }
      },
      {
        path: 'classification',
        component: () => import('@/views/asset/classification/index'),
        name: 'AssetClassification',
        meta: { title: '资产分类设置', icon: 'el-icon-folder' }
      },
      {
        path: 'inventory',
        component: () => import('@/views/asset/inventory/index'),
        name: 'AssetInventory',
        meta: { title: '资产清单管理', icon: 'el-icon-files' }
      },
      {
        path: 'labelPage',
        component: () => import('@/views/asset/labelPage/index'),
        name: 'AssetLabel',
        meta: { title: '资产标签设置', icon: 'el-icon-printer' }
      }
    ]
  }
]

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes
})

export default router 