/**
 * 用户鉴权相关工具方法
 */

/**
 * 获取当前登录用户ID
 * @returns {string} 用户ID
 */
export function getUserId() {
  // 从本地存储中获取用户信息
  const userInfo = localStorage.getItem('userInfo')
  if (userInfo) {
    try {
      const user = JSON.parse(userInfo)
      return user.id || user.userId || ''
    } catch (e) {
      console.error('解析用户信息失败', e)
      return ''
    }
  }
  return ''
}

/**
 * 获取用户信息
 * @returns {Object} 用户信息对象
 */
export function getUserInfo() {
  const userInfo = localStorage.getItem('userInfo')
  if (userInfo) {
    try {
      return JSON.parse(userInfo)
    } catch (e) {
      console.error('解析用户信息失败', e)
      return {}
    }
  }
  return {}
}

/**
 * 保存用户信息到本地存储
 * @param {Object} userInfo 用户信息对象
 */
export function setUserInfo(userInfo) {
  if (userInfo) {
    localStorage.setItem('userInfo', JSON.stringify(userInfo))
  }
}

/**
 * 清除用户信息
 */
export function clearUserInfo() {
  localStorage.removeItem('userInfo')
} 