import axios from 'axios'
import { Message } from 'element-ui'
import { API_SUCCESS_CODE } from './constants'

// 创建axios实例
const service = axios.create({
  // baseURL: '/', // 修改为相对路径，使用代理
  baseURL: process.env.VUE_APP_BASE_API, // 使用环境变量中的接口地址

  timeout: 10000 // 请求超时时间
})

// 请求拦截器
service.interceptors.request.use(
  config => {
    // 可以在这里添加请求头等信息
    return config
  },
  error => {
    console.log(error)
    return Promise.reject(error)
  }
)

// 响应拦截器
service.interceptors.response.use(
  response => {
    // 如果是blob类型（文件下载），直接返回
    if (response.config.responseType === 'blob') {
      return response
    }
    
    const res = response.data
    // 如果返回的状态码不是成功码，则判断为错误
    if (res.code !== API_SUCCESS_CODE) {
      Message({
        message: res.msg || res.message || '系统错误',
        type: 'error',
        duration: 5 * 1000
      })
      return Promise.reject(new Error(res.msg || res.message || '系统错误'))
    } else {
      return res
    }
  },
  error => {
    console.log('err' + error)
    Message({
      message: error.message,
      type: 'error',
      duration: 5 * 1000
    })
    return Promise.reject(error)
  }
)

export default service 